from django.db import models
from django.utils.translation import ugettext_lazy as _

class Section(models.Model):
	"""
	Sections are encapsulations for specific content parts on a webpage. 
	It governs a number of content entities, and is designed to integrate user-created entities seamlessly.
	"""
	class Meta:
		verbose_name = _('section')
		verbose_name_plural = _('sections')
	identifier = models.CharField(_('identifier'), help_text=_('This should only contain alphanumeric characters and underscores (\'_\'). Do not change this unless you know what you\'re doing.'), max_length=50, unique=True)
	title = models.CharField(_('title'), help_text=_('This is used as a nicer, alternative display-name for the identifier. It does not show up on the site'), max_length=200, blank=True, default='')
	
	def __unicode__(self):
		if len(self.title) > 0:
			return self.title
		return self.identifier

class Entity(models.Model):
	"""
	A text entity is the most basic data type allowed in a section.
	It contains basic facilities for adding text (with or without html-support) to a section.
	"""
	class Meta:
		verbose_name = _('text entity')
		verbose_name_plural = _('text entities')
		abstract = True
	title = models.CharField(_('title'), help_text=_('This is used for documentation-purposes only, and does not show up on the site.'), max_length=200, default='Text')
	identifier = models.CharField(_('identifier'), help_text=_('This should only contain alphanumeric characters and underscores (\'_\'). Do not change this unless you know what you\'re doing.'), max_length=50)
	section = models.ForeignKey(Section, help_text=_('The section this entity belongs to'), verbose_name=_('section'))
	visible = models.BooleanField(_('visible'), help_text=_('If this is unchecked, the content will not be published on the site'), default=True)
	created = models.DateTimeField(_('created'), auto_now_add=True)
	last_changed = models.DateTimeField(_('last changed'), auto_now=True)

	def __unicode__(self):
		return self.title

class TextEntity(Entity):
	"""
	A text entity is the most basic data type allowed in a section. It contains a string of at most 250 characters.
	"""
	class Meta:
		verbose_name = _('text entity')
		verbose_name_plural = _('text entities')
	content = models.CharField(_('content'), max_length=250, help_text=_('This is the content that will be presented on the site'), default='')
	
class LongTextEntity(Entity):
	"""
	A long text entity stores a text blob in the database.
	It can be set to html or plain text mode.
	"""
	class Meta:
		verbose_name = _('long text entity')
		verbose_name_plural = _('long text entities')
	content = models.TextField(_('content'), help_text=_('This is the content that will be presented on the site'), default='')
	use_html = models.BooleanField(_('use html'), help_text=_('If this option is activated, the content will be interpreted as HTML'), default=False)


